Class: Tango::Api::Resources::ChoiceProducts
- Defined in:
- lib/tango/api/resources/choice_products.rb
Overview
Resource for Choice Products catalog and details.
Instance Method Summary collapse
-
#catalog(choice_product_utid, params = {}) ⇒ Object
GET /choiceProducts/choiceProductUtid/catalog Supports typical catalog query params, including filters and verbosity flags.
-
#get(params = {}) ⇒ Object
GET /choiceProducts Params may include: rewardName, currencyCode, countries: [].
-
#get_for_utid(utid) ⇒ Object
GET /choiceProducts/utid.
Methods inherited from Base
Constructor Details
This class inherits a constructor from Tango::Api::Resources::Base
Instance Method Details
#catalog(choice_product_utid, params = {}) ⇒ Object
GET /choiceProducts/choiceProductUtid/catalog Supports typical catalog query params, including filters and verbosity flags.
21 22 23 |
# File 'lib/tango/api/resources/choice_products.rb', line 21 def catalog(choice_product_utid, params = {}) get_json("choiceProducts/#{choice_product_utid}/catalog", params) end |
#get(params = {}) ⇒ Object
GET /choiceProducts Params may include: rewardName, currencyCode, countries: []
10 11 12 |
# File 'lib/tango/api/resources/choice_products.rb', line 10 def get(params = {}) get_json("choiceProducts", params) end |
#get_for_utid(utid) ⇒ Object
GET /choiceProducts/utid
15 16 17 |
# File 'lib/tango/api/resources/choice_products.rb', line 15 def get_for_utid(utid) get_json("choiceProducts/#{utid}") end |